@@ -13,7 +13,7 @@ import tempfile
 import warnings
 from numbers import Number
 from types import ModuleType
-from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Tuple
+from typing import TYPE_CHECKING, Dict, List, Optional
 
 import numpy as np
 import pandas as pd
@@ -428,7 +428,7 @@ class Audio(OutputComponent):
     def __init__(self, type: str = "auto", label: Optional[str] = None):
         """
         Parameters:
-        type (str): Type of value to be passed to component. "numpy" returns a 2-set tuple with an integer sample_rate and the data numpy.array of shape (samples, 2), "file" returns a temporary file path to the saved wav audio file, "auto" detects return type.
+        type (str): Type of value to be passed to component. "numpy" returns a 2-set tuple with an integer sample_rate and the data as 16-bit int numpy.array of shape (samples, 2), "file" returns a temporary file path to the saved wav audio file, "auto" detects return type.
         label (str): component name in interface.
         """
         self.type = type
@@ -794,9 +794,45 @@ class Timeseries(OutputComponent):
         return json.loads(data)
 
 
+class Chatbot(OutputComponent):
+    """
+    Component displays a chatbot output showing both user submitted messages and responses
+    Output type: List[Tuple[str, str]]
+    Demos: chatbot
+    """
+
+    def __init__(self, label: Optional[str] = None):
+        """
+        Parameters:
+        label (str): component name in interface (not used).
+        """
+        super().__init__(label)
+
+    def get_template_context(self):
+        return {**super().get_template_context()}
+
+    @classmethod
+    def get_shortcut_implementations(cls):
+        return {
+            "chatbot": {},
+        }
+
+    def postprocess(self, y):
+        """
+        Parameters:
+        y (List[Tuple[str, str]]): List of tuples representing the message and response
+        Returns:
+        (List[Tuple[str, str]]): Returns same list of tuples
+
+        """
+        return y
+
+
 class State(OutputComponent):
     """
     Special hidden component that stores state across runs of the interface.
+    Output type: Any
+    Demos: chatbot
     """
 
     def __init__(self, label: Optional[str] = None):
